import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:flutter_svg/svg.dart';
import 'package:syncrow_web/pages/spaces_management/all_spaces/bloc/space_management_bloc.dart';
import 'package:syncrow_web/pages/spaces_management/all_spaces/bloc/space_management_event.dart';
import 'package:syncrow_web/pages/spaces_management/space_model/bloc/space_model_bloc.dart';

import 'package:syncrow_web/pages/spaces_management/space_model/bloc/space_model_event.dart';
import 'package:syncrow_web/pages/spaces_management/space_model/models/space_template_model.dart';
import 'package:syncrow_web/pages/spaces_management/space_model/widgets/dialog/delete_space_model_dialog.dart';
import 'package:syncrow_web/pages/spaces_management/space_model/widgets/dynamic_product_widget.dart';
import 'package:syncrow_web/pages/spaces_management/space_model/widgets/dynamic_room_widget.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/constants/assets.dart';

class SpaceModelCardWidget extends StatelessWidget {
  final SpaceTemplateModel model;
  final BuildContext? pageContext;
  final bool topActionsDisabled;

  const SpaceModelCardWidget({
    Key? key,
    required this.model,
    this.pageContext,
    this.topActionsDisabled = true,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final Map<String, int> productTagCount = {};

    if (model.tags != null) {
      for (var tag in model.tags!) {
        final prodIcon = tag.product?.icon ?? 'Unknown';
        productTagCount[prodIcon] = (productTagCount[prodIcon] ?? 0) + 1;
      }
    }

    if (model.subspaceModels != null) {
      for (var subspace in model.subspaceModels!) {
        if (subspace.tags != null) {
          for (var tag in subspace.tags!) {
            final prodIcon = tag.product?.icon ?? 'Unknown';
            productTagCount[prodIcon] = (productTagCount[prodIcon] ?? 0) + 1;
          }
        }
      }
    }

    return LayoutBuilder(
      builder: (context, constraints) {
        bool showOnlyName = constraints.maxWidth < 250;
        return Container(
          padding: const EdgeInsets.all(16.0),
          decoration: BoxDecoration(
            color: Colors.white,
            borderRadius: BorderRadius.circular(10),
            boxShadow: [
              BoxShadow(
                color: Colors.grey.withOpacity(0.5),
                spreadRadius: 2,
                blurRadius: 5,
                offset: const Offset(0, 3),
              ),
            ],
          ),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Row(
                children: [
                  Expanded(
                    child: Text(
                      model.modelName,
                      style:
                          Theme.of(context).textTheme.headlineMedium?.copyWith(
                                color: Colors.black,
                                fontWeight: FontWeight.bold,
                              ),
                      maxLines: 1,
                      overflow: TextOverflow.ellipsis,
                    ),
                  ),
                  if (!topActionsDisabled)
                    GestureDetector(
                      onTap: () => _showDeleteDialog(context),
                      child: Container(
                        width: 36, // Adjust size as needed
                        height: 36,
                        decoration: BoxDecoration(
                          shape: BoxShape.circle,
                          color: Colors.white,
                          boxShadow: [
                            BoxShadow(
                              color: Colors.black.withOpacity(0.1),
                              spreadRadius: 2,
                              blurRadius: 5,
                              offset: const Offset(0, 2),
                            ),
                          ],
                        ),
                        child: Center(
                          child: SvgPicture.asset(
                            Assets.deleteSpaceModel, // Your actual SVG path
                            width: 20,
                            height: 20,
                            colorFilter: const ColorFilter.mode(
                                Colors.grey, BlendMode.srcIn),
                          ),
                        ),
                      ),
                    ),
                ],
              ),
              if (!showOnlyName) ...[
                const SizedBox(height: 10),
                Expanded(
                  child: Row(
                    children: [
                      // Left Container
                      Expanded(
                        flex: 1, // Distribute space proportionally
                        child: Container(
                          padding: const EdgeInsets.all(8.0),
                          child: LayoutBuilder(
                            builder: (context, constraints) {
                              return Align(
                                alignment: Alignment.topLeft,
                                child: DynamicRoomWidget(
                                  subspaceModels: model.subspaceModels,
                                  maxWidth: constraints.maxWidth,
                                  maxHeight: constraints.maxHeight,
                                ),
                              );
                            },
                          ),
                        ),
                      ),
                      if (productTagCount.isNotEmpty &&
                          model.subspaceModels != null)
                        Container(
                          width: 1.0,
                          color: ColorsManager.softGray,
                          margin: const EdgeInsets.symmetric(vertical: 6.0),
                        ),
                      Expanded(
                        flex: 1, // Distribute space proportionally
                        child: Container(
                          padding: const EdgeInsets.all(8.0),
                          child: LayoutBuilder(
                            builder: (context, constraints) {
                              return Align(
                                  alignment: Alignment.topLeft,
                                  child: DynamicProductWidget(
                                      productTagCount: productTagCount,
                                      maxWidth: constraints.maxWidth,
                                      maxHeight: constraints.maxHeight));
                            },
                          ),
                        ),
                      ),
                    ],
                  ),
                ),
              ]
            ],
          ),
        );
      },
    );
  }

  void _showDeleteDialog(BuildContext context) {
    showDialog(
      context: context,
      barrierDismissible: true,
      builder: (BuildContext dialogContext) {
        return DeleteSpaceModelDialog(
          onConfirmDelete: () {
            if (pageContext != null) {
              pageContext!.read<SpaceModelBloc>().add(
                    DeleteSpaceModel(spaceModelUuid: model.uuid ?? ''),
                  );

              pageContext!.read<SpaceManagementBloc>().add(
                    DeleteSpaceModelFromCache(model.uuid ?? ''),
                  );
            }
          },
        );
      },
    );
  }
}
